import { __decorate } from 'tslib';
import { firstValueFrom, from, map, filter, defaultIfEmpty, catchError, of, BehaviorSubject, ReplaySubject } from 'rxjs';
import * as i0 from '@angular/core';
import { Pipe, Injectable, Inject, Component, ChangeDetectionStrategy, Input } from '@angular/core';
import * as i5 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as io from 'io-ts';
import { pipe } from 'fp-ts/es6/function';
import { getOrElse } from 'fp-ts/es6/Either';
import * as i6 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i7 from '@angular/material/tabs';
import { MatTabsModule } from '@angular/material/tabs';
import hljs from 'highlight.js';
import * as iot from 'io-ts-types';
import * as i1 from '@angular/common/http';
import { untilDestroyed, UntilDestroy } from '@ngneat/until-destroy';
import * as i1$1 from '@angular/platform-browser';

/**
 * Validate that the value is a string.
 */
function isString(value) {
    return typeof value === 'string' || value instanceof String;
}
/**
 * Validate that the value is a string that is non-empty.
 */
function isNonEmptyString(value) {
    return isString(value) && value.length > 0 && value.trim().length > 0;
}
function isStringArray(value) {
    return Array.isArray(value) && value.every((v) => typeof v === 'string');
}
function isNonEmptyValue(value) {
    return value !== null && value !== undefined;
}
/**
 * Decode by parsing json object of string value.
 */
const parsedJsonFromStringCodec = new io.Type('ParsedJSONFromString', (potentiallyUnknownValue) => true, (stringValue, context) => {
    try {
        return io.success(JSON.parse(stringValue));
    }
    catch {
        return io.failure(stringValue, context);
    }
}, (unknownValue) => JSON.stringify(unknownValue));
/**
 * Decode value using a passed codec and its' decoder.
 *
 * @param codec Codec used to decode value.
 *
 * @typeParam A - Static type (expected)
 * @typeParam O - Encode outputs of type
 * @typeParam I - Decode input of type
 *
 * @returns The decoeded value or null if an error occurs.
 */
function decodeValueElseNull(codec) {
    return (value) => pipe(codec.decode(value), getOrElse(() => null));
}

class GistFileFilterPipe {
    transform(files, displayOnlyFileNames) {
        if (!files) {
            return [];
        }
        if (!displayOnlyFileNames || displayOnlyFileNames === '') {
            return files;
        }
        if (isNonEmptyString(displayOnlyFileNames)) {
            return (files.filter(({ filename }) => displayOnlyFileNames === filename) ?? []);
        }
        if (isStringArray(displayOnlyFileNames)) {
            return files.filter(({ filename }) => displayOnlyFileNames.includes(filename));
        }
        return files;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: GistFileFilterPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.1.5", ngImport: i0, type: GistFileFilterPipe, isStandalone: true, name: "gistFileFilter" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: GistFileFilterPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'gistFileFilter' }]
        }] });

class NgxGistThemeService {
    document;
    constructor(document) {
        this.document = document;
    }
    importElHljsTheme = null;
    setTheme(hilightJsTheme) {
        const hljsThemeId = 'hljs-theme-import';
        const hljsThemeLinkEl = this.document.getElementById(hljsThemeId);
        if (hljsThemeLinkEl && hilightJsTheme === 'default') {
            // Default theme already in use, return.
            return;
        }
        else if (hljsThemeLinkEl &&
            hilightJsTheme !== 'default') {
            // Override previously used theme, but remove it first.
            this.document.head.removeChild(hljsThemeLinkEl);
        }
        const version = '11.11.1'; // Update with version!
        const url = `highlight.js@${version}/styles/${hilightJsTheme}.css`;
        this.importElHljsTheme = this.document.createElement('link');
        this.importElHljsTheme.href = `https://unpkg.com/${url}`;
        this.importElHljsTheme.rel = 'stylesheet';
        this.importElHljsTheme.id = hljsThemeId;
        this.document.head.appendChild(this.importElHljsTheme);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistThemeService, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistThemeService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistThemeService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }] });

class NgxGistLineNumbersService {
    document;
    constructor(document) {
        this.document = document;
    }
    isLoaded = false;
    async load() {
        if (this.isLoaded ||
            typeof this.document.defaultView?.hljs?.initLineNumbersOnLoad === 'function') {
            return;
        }
        try {
            if (this.document.defaultView) {
                // Ensure hljs is available before we load the dependent library
                this.document.defaultView.hljs = hljs;
            }
            else {
                throw new Error(`Unable to access default view to apply "highlight.js" package.`);
            }
            const result = await firstValueFrom(this.loadHljsLineNumbersLibrary());
            if (result) {
                this.document.defaultView?.hljs?.initLineNumbersOnLoad?.();
            }
        }
        catch (e) {
            console.error(e);
        }
        finally {
            this.isLoaded = true;
        }
    }
    loadHljsLineNumbersLibrary() {
        return from(import('highlightjs-line-numbers.js')).pipe(map((module) => module?.default), // Optional chaining makes it cleaner
        filter(Boolean), // `Boolean` acts as a filter to remove falsy values
        defaultIfEmpty(null));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistLineNumbersService, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistLineNumbersService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistLineNumbersService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }] });

class NgxGist {
    constructor(args) {
        this.comments = args.comments;
        this.comments_url = args.comments_url;
        this.commits_url = args.commits_url;
        this.created_at = new Date(args.created_at);
        this.description = args.description;
        this.files = args.files;
        this.forks = args.forks;
        this.forks_url = args.forks_url;
        this.git_pull_url = args.git_pull_url;
        this.git_push_url = args.git_push_url;
        this.history = args.history;
        this.html_url = args.html_url;
        this.id = args.id;
        this.node_id = args.node_id;
        this.owner = args.owner;
        this.public = args.public;
        this.truncated = args.truncated;
        this.updated_at = new Date(args.updated_at);
        this.url = args.url;
        this.user = args.user;
        // Additional properties
        this.languageOverride = args.languageOverride;
        const highlightedFiles = [];
        for (const key in this.files) {
            if (this.files[key]) {
                const file = this.files[key];
                highlightedFiles.push({
                    ...file,
                    highlightedContent: getHighlightedContent(file.content),
                });
            }
        }
        this.highlightedFiles = highlightedFiles;
    }
    /** Core gist properties */
    /* eslint-disable @typescript-eslint/naming-convention */
    comments;
    comments_url;
    commits_url;
    created_at;
    description;
    files;
    forks;
    forks_url;
    git_pull_url;
    git_push_url;
    history;
    html_url;
    id;
    node_id;
    owner;
    public;
    truncated;
    updated_at;
    url;
    user;
    /* eslint-enable @typescript-eslint/naming-convention */
    /** Additional properties */
    highlightedFiles;
    languageOverride;
    /**
     * Create a local, static gist object. Do not use this for fetched data.
     * Used for creating and displaying local code samples.
     *
     * Use `deserialize` sibling function for remote "unknown" responses.
     *
     * @param args Minimally necessary paramaters for displaying local code.
     * @returns A 'partial' model in which unnecessary fields are dummny data.
     */
    static create(args) {
        const files = args.files.reduce((prev, curr) => {
            const file = {
                // Passed in values, use these.
                content: curr.content,
                filename: curr.filename,
                // Leave these empty, not needed for a local, static model.
                language: '',
                raw_url: '',
                size: 0,
                truncated: false,
                type: '',
            };
            return {
                ...prev,
                [curr.filename]: file,
            };
        }, {});
        return new NgxGist({
            // Properties with settable values. These are the mimimum values needed
            // for displaying non "remote".
            created_at: args.created_at ? new Date(args.created_at) : new Date(),
            description: args.description ?? '',
            files,
            languageOverride: args.languageOverride,
            // Empty properties that aren't needed for displaying non "remote" gists
            comments: 0,
            comments_url: '',
            commits_url: '',
            forks: [],
            forks_url: '',
            git_pull_url: '',
            git_push_url: '',
            history: [],
            html_url: '',
            id: '',
            node_id: '',
            owner: undefined,
            public: true,
            truncated: false,
            updated_at: new Date(),
            url: '',
            user: undefined,
        });
    }
    /**
     * Deserialize and decode fetched/unknown data into the full model.
     *
     * @param value Unknown value, but expects a full model either by object or JSON string.
     * @returns Either the full model or null if deserialization fails.
     */
    static deserialize(value) {
        const decoded = 
        // Decode as object or continue
        decodeValueElseNull(gistCodec)(value) ||
            // Decode as string or return null
            (isNonEmptyString(value)
                ? decodeValueElseNull(gistFromJsonStringCodec)(value)
                : null);
        return decoded
            ? new NgxGist({
                ...decoded,
                created_at: new Date(decoded.created_at),
                updated_at: new Date(decoded.updated_at),
            })
            : null;
    }
}
function getHighlightedContent(baseContent, languageOverride) {
    let highlighted = baseContent;
    if (languageOverride) {
        highlighted = hljs.highlight(baseContent, {
            language: languageOverride,
        }).value;
    }
    else {
        highlighted = hljs.highlightAuto(baseContent).value;
    }
    return highlighted;
}
const gitHubUserCodec = io.readonly(io.type({
    avatar_url: io.string,
    events_url: io.string,
    followers_url: io.string,
    following_url: io.string,
    gists_url: io.string,
    gravatar_id: io.string,
    html_url: io.string,
    id: io.number,
    login: io.string,
    node_id: io.string,
    organizations_url: io.string,
    received_events_url: io.string,
    repos_url: io.string,
    site_admin: io.boolean,
    starred_url: io.string,
    subscriptions_url: io.string,
    type: io.string,
    url: io.string,
}), 'GitHubUser');
const gistHistoryChangeStatusCodec = io.readonly(io.type({
    additions: io.number,
    deletions: io.number,
    total: io.number,
}), 'GistChangeStatus');
const gistHistoryCodec = io.readonly(io.type({
    change_status: gistHistoryChangeStatusCodec,
    committed_at: io.union([iot.date, io.string]),
    url: io.string,
    user: gitHubUserCodec,
    version: io.string,
}), 'GistHistory');
const gistFilesContent = io.type({
    content: io.string,
    filename: io.string,
    language: io.string,
    raw_url: io.string,
    size: io.number,
    truncated: io.boolean,
    type: io.string,
});
const gistFilesCodec = io.record(io.string, gistFilesContent);
const gistCodec = io.readonly(io.intersection([
    io.type({
        comments: io.number,
        comments_url: io.string,
        commits_url: io.string,
        created_at: io.union([iot.date, io.string]),
        description: io.string,
        files: gistFilesCodec,
        forks: io.UnknownArray,
        forks_url: io.string,
        git_pull_url: io.string,
        git_push_url: io.string,
        history: io.array(gistHistoryCodec),
        html_url: io.string,
        id: io.string,
        node_id: io.string,
        public: io.boolean,
        truncated: io.boolean,
        updated_at: io.union([iot.date, io.string]),
        url: io.string,
    }),
    io.partial({
        owner: io.union([gitHubUserCodec, io.undefined]),
        user: io.union([io.unknown, io.null, io.undefined]),
    }),
]), 'Gist');
const gistFromJsonStringCodec = parsedJsonFromStringCodec.pipe(gistCodec, 'GistFromJsonString');

class NgxGistService {
    httpClient;
    constructor(httpClient) {
        this.httpClient = httpClient;
    }
    delimiter = '||';
    /**
     * Fetch gist data from GitHub.
     *
     * @param gistId GitHub gist id
     * @returns Full gist model on success, undefined on error, null on deserialize failure.
     */
    get(gistId) {
        return this.httpClient
            .get(`https://api.github.com/gists/${gistId}`)
            .pipe(catchError((error) => {
            console.error(error);
            return of(undefined);
        }), map((response) => NgxGist.deserialize(response) ?? null));
    }
    getFromCache(gistId) {
        const key = `gist${this.delimiter + gistId}`;
        const value = localStorage.getItem(key);
        if (value === null || !isNonEmptyString(value)) {
            // Doesn't exist in memory
            return null;
        }
        const storedGist = decodeValueElseNull(storedGistFromJsonStringCodec)(value);
        if (!storedGist) {
            // Failed to deserialize stored data (corruption?). Remote it and return.
            localStorage.removeItem(key);
            return null;
        }
        const now = new Date();
        if (now.getTime() > storedGist.expiration) {
            // Stored value has since expired, remove it and return.
            localStorage.removeItem(key);
            return null;
        }
        const gist = storedGist.value;
        // All is good, return unexpired gist
        return new NgxGist({
            ...gist,
            created_at: new Date(gist.created_at),
            updated_at: new Date(gist.updated_at),
        });
    }
    setToCache(gist, expiresInMin) {
        const key = `gist${this.delimiter + gist.id}`;
        const now = new Date();
        const expiresInMs = expiresInMin ? expiresInMin * 60000 : 0;
        const value = {
            expiration: now.getTime() + expiresInMs,
            value: gist,
        };
        const stringValue = JSON.stringify(value);
        localStorage.setItem(key, stringValue);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }] });
const storedGistCodec = io.readonly(io.type({
    expiration: io.number,
    value: gistCodec,
}), 'StoredGist');
const storedGistFromJsonStringCodec = parsedJsonFromStringCodec.pipe(storedGistCodec, 'StoredGistFromJsonString');

let NgxGistComponent = class NgxGistComponent {
    document;
    domSanitizer;
    ngxGistLineNumbersService;
    ngxGistService;
    ngxGistThemeService;
    constructor(document, domSanitizer, ngxGistLineNumbersService, ngxGistService, ngxGistThemeService) {
        this.document = document;
        this.domSanitizer = domSanitizer;
        this.ngxGistLineNumbersService = ngxGistLineNumbersService;
        this.ngxGistService = ngxGistService;
        this.ngxGistThemeService = ngxGistThemeService;
    }
    /**
     * Display in the DOM only the selected filename(s) from the gists files array.
     *
     * Default: `undefined`
     *
     * Example: `'my-styles.scss'` or `'super-feature.ts'`
     *
     * Tip: Can be either a string or string array. File names much match exactly,
     * be sure to remove any leading or trailing whitespace in the provided strings.
     */
    displayOnlyFileNames;
    /**
     * Optionally hide the gist link which opens the gist on GitHub. The gist links
     * automatically dispaly for remote gists, but can be hidden with this feature.
     *
     * Default: `false`
     */
    hideGistLink = false;
    /**
     * Provide a static gist model here directly which will be displayed if
     * no `gistId` is provided for remote fetching. Also this model will be
     * displayed should a fetch fail when retrieving `gistId`, or overwritten
     * once the pertaining `gistId` data is fetched.
     *
     * Default: `undefined`
     */
    set gist(value) {
        this.gistSubject.next(value);
    }
    gistSubject = new BehaviorSubject(undefined);
    gistChanges = this.gistSubject.asObservable();
    /**
     * Provide the GitHub gist id to be fetched and loaded. This can be found in
     * URL of the gists you create. For example the id `TH1515th31DT0C0PY` in:
     * https://gist.github.com/FakeUserName/TH1515th31DT0C0PY
     *
     * Default: `undefined`
     *
     * Tip: Alternatively, provide a value directly in the sibling input `gist`.
     */
    set gistId(value) {
        this.gistIdSubject.next(value);
    }
    gistIdSubject = new ReplaySubject(1);
    gistIdChanges = this.gistIdSubject.asObservable();
    /**
     * The `highlight.js` code theme to use and display.
     *
     * Default: `undefined`
     *
     * Note: Only _one_ theme can be loaded on a single page at a time! The first
     * theme to load will apply to all gists on the page.
     */
    codeTheme;
    /**
     * Display or hide the line numbers in your gist code snippets.
     *
     * Default: `true`
     */
    showLineNumbers = true;
    /**
     * Cache the GitHub gist request in local memory for 24 hours. GitHub has a
     * request limit, so this helps in reducing bandwidth. Loads previously
     * fetched gist content from the users machine on refresh and page re-visits.
     *
     * Default: `true`
     */
    useCache = true;
    async ngOnInit() {
        // Load theme
        this.setHljsTheme();
        // Load line numbers
        if (this.showLineNumbers) {
            await this.ngxGistLineNumbersService.load();
        }
        // Load gist(s) async
        this.gistIdChanges
            .pipe(filter(isNonEmptyValue), untilDestroyed(this))
            .subscribe(async (gistId) => {
            if (this.useCache) {
                const cachedValue = this.ngxGistService.getFromCache(gistId);
                if (cachedValue) {
                    // Value is cached and not previously expired, use it.
                    this.gist = cachedValue;
                    return;
                }
            }
            await this.fetchAndSetGist(gistId);
        });
    }
    async fetchAndSetGist(gistId) {
        // Fetch and hydrate model or fallback to initial gist.
        const fetcheGist = (await firstValueFrom(this.ngxGistService.get(gistId))) ?? undefined;
        this.gist = fetcheGist;
        if (this.useCache && fetcheGist) {
            // Set value in cache for reuse saving on the amount of HTTP requests.
            // Set refresh time to be a hard coded 24 hours. This was once configurable
            // but I decided against it for simplicities sake on ease of use.
            this.ngxGistService.setToCache(fetcheGist, 1440);
        }
    }
    setHljsTheme() {
        if (!this.codeTheme) {
            return;
        }
        this.ngxGistThemeService.setTheme(this.codeTheme);
    }
    applyLineNumbers(highlightedConent) {
        if (this.showLineNumbers &&
            this.document.defaultView?.hljs &&
            typeof this.document.defaultView.hljs.lineNumbersValue === 'function') {
            return this.domSanitizer.bypassSecurityTrustHtml(this.document.defaultView.hljs.lineNumbersValue(highlightedConent));
        }
        return highlightedConent;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistComponent, deps: [{ token: DOCUMENT }, { token: i1$1.DomSanitizer }, { token: NgxGistLineNumbersService }, { token: NgxGistService }, { token: NgxGistThemeService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.5", type: NgxGistComponent, isStandalone: true, selector: "ngx-gist", inputs: { displayOnlyFileNames: "displayOnlyFileNames", hideGistLink: "hideGistLink", gist: "gist", gistId: "gistId", codeTheme: "codeTheme", showLineNumbers: "showLineNumbers", useCache: "useCache" }, providers: [
            NgxGistLineNumbersService,
            NgxGistService,
            NgxGistThemeService,
        ], ngImport: i0, template: "<mat-card class=\"code-container\">\n  <mat-tab-group *ngIf=\"gistChanges | async as gist; else loading\">\n    <mat-tab\n      *ngFor=\"\n        let file of gist.highlightedFiles\n          | gistFileFilter: displayOnlyFileNames\n      \"\n      [label]=\"file.filename\"\n    >\n      <pre>\n        <code\n          *ngIf=\"applyLineNumbers(file.highlightedContent) as content\"\n          [innerHTML]=\"content\"\n        ></code>\n        <ng-template #error>\n          <code>Error loading code...</code>\n        </ng-template>\n      </pre>\n    </mat-tab>\n  </mat-tab-group>\n  <mat-card-footer *ngIf=\"gistIdChanges | async as gid\">\n    <a\n      *ngIf=\"!hideGistLink\"\n      target=\"_blank\"\n      [href]=\"'https://gist.github.com/' + gid\"\n    >\n      \uD83D\uDD17 Open Gist on GitHub\n    </a>\n  </mat-card-footer>\n  <ng-template #loading>Loading Code Snippet...</ng-template>\n</mat-card>\n", styles: ["@import\"https://fonts.googleapis.com/icon?family=Material+Icons\";pre{display:flex;margin-top:0;margin-bottom:0;word-wrap:break-word}pre code{flex:1;line-height:1.5em;font-size:14px;min-height:100%;padding:1em 1.2em}::ng-deep mat-card.code-container{padding:0;margin-bottom:3em}::ng-deep mat-card.code-container mat-card-footer{height:1rem;border-top:1px solid rgba(0,0,0,.12);padding:.75rem;margin:0;display:flex;flex-direction:row-reverse}::ng-deep mat-card.code-container mat-card-footer a{font-size:.75rem;text-decoration:none;display:flex;align-items:center}::ng-deep mat-card.code-container mat-card-footer a>mat-icon{font-size:1.5rem;position:relative;top:0;padding-right:.25rem}::ng-deep pre>code.hljs-line-numbers{padding:0!important}::ng-deep .hljs{margin:0;padding:10px;transition:border ease 1s}::ng-deep .hljs-ln{padding:8px 0}::ng-deep .hljs-ln tr:first-child td{padding-top:8px!important}::ng-deep .hljs-ln tr:last-child td{padding-bottom:8px!important}::ng-deep td.hljs-ln-numbers{-webkit-user-select:none;user-select:none;text-align:center;border-right:1px solid gray;vertical-align:top;padding-right:8px!important;padding-left:8px!important}::ng-deep td.hljs-ln-code{padding-left:8px!important}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i5.AsyncPipe, name: "async" }, { kind: "pipe", type: GistFileFilterPipe, name: "gistFileFilter" }, { kind: "ngmodule", type: MatCardModule }, { kind: "component", type: i6.MatCard, selector: "mat-card", inputs: ["appearance"], exportAs: ["matCard"] }, { kind: "directive", type: i6.MatCardFooter, selector: "mat-card-footer" }, { kind: "ngmodule", type: MatTabsModule }, { kind: "component", type: i7.MatTab, selector: "mat-tab", inputs: ["disabled", "label", "aria-label", "aria-labelledby", "labelClass", "bodyClass"], exportAs: ["matTab"] }, { kind: "component", type: i7.MatTabGroup, selector: "mat-tab-group", inputs: ["color", "fitInkBarToContent", "mat-stretch-tabs", "mat-align-tabs", "dynamicHeight", "selectedIndex", "headerPosition", "animationDuration", "contentTabIndex", "disablePagination", "disableRipple", "preserveContent", "backgroundColor", "aria-label", "aria-labelledby"], outputs: ["selectedIndexChange", "focusChange", "animationDone", "selectedTabChange"], exportAs: ["matTabGroup"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
};
NgxGistComponent = __decorate([
    UntilDestroy()
], NgxGistComponent);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.5", ngImport: i0, type: NgxGistComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-gist', standalone: true, imports: [
                        CommonModule,
                        GistFileFilterPipe,
                        MatCardModule,
                        MatTabsModule,
                    ], providers: [
                        NgxGistLineNumbersService,
                        NgxGistService,
                        NgxGistThemeService,
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<mat-card class=\"code-container\">\n  <mat-tab-group *ngIf=\"gistChanges | async as gist; else loading\">\n    <mat-tab\n      *ngFor=\"\n        let file of gist.highlightedFiles\n          | gistFileFilter: displayOnlyFileNames\n      \"\n      [label]=\"file.filename\"\n    >\n      <pre>\n        <code\n          *ngIf=\"applyLineNumbers(file.highlightedContent) as content\"\n          [innerHTML]=\"content\"\n        ></code>\n        <ng-template #error>\n          <code>Error loading code...</code>\n        </ng-template>\n      </pre>\n    </mat-tab>\n  </mat-tab-group>\n  <mat-card-footer *ngIf=\"gistIdChanges | async as gid\">\n    <a\n      *ngIf=\"!hideGistLink\"\n      target=\"_blank\"\n      [href]=\"'https://gist.github.com/' + gid\"\n    >\n      \uD83D\uDD17 Open Gist on GitHub\n    </a>\n  </mat-card-footer>\n  <ng-template #loading>Loading Code Snippet...</ng-template>\n</mat-card>\n", styles: ["@import\"https://fonts.googleapis.com/icon?family=Material+Icons\";pre{display:flex;margin-top:0;margin-bottom:0;word-wrap:break-word}pre code{flex:1;line-height:1.5em;font-size:14px;min-height:100%;padding:1em 1.2em}::ng-deep mat-card.code-container{padding:0;margin-bottom:3em}::ng-deep mat-card.code-container mat-card-footer{height:1rem;border-top:1px solid rgba(0,0,0,.12);padding:.75rem;margin:0;display:flex;flex-direction:row-reverse}::ng-deep mat-card.code-container mat-card-footer a{font-size:.75rem;text-decoration:none;display:flex;align-items:center}::ng-deep mat-card.code-container mat-card-footer a>mat-icon{font-size:1.5rem;position:relative;top:0;padding-right:.25rem}::ng-deep pre>code.hljs-line-numbers{padding:0!important}::ng-deep .hljs{margin:0;padding:10px;transition:border ease 1s}::ng-deep .hljs-ln{padding:8px 0}::ng-deep .hljs-ln tr:first-child td{padding-top:8px!important}::ng-deep .hljs-ln tr:last-child td{padding-bottom:8px!important}::ng-deep td.hljs-ln-numbers{-webkit-user-select:none;user-select:none;text-align:center;border-right:1px solid gray;vertical-align:top;padding-right:8px!important;padding-left:8px!important}::ng-deep td.hljs-ln-code{padding-left:8px!important}\n"] }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i1$1.DomSanitizer }, { type: NgxGistLineNumbersService }, { type: NgxGistService }, { type: NgxGistThemeService }], propDecorators: { displayOnlyFileNames: [{
                type: Input
            }], hideGistLink: [{
                type: Input
            }], gist: [{
                type: Input
            }], gistId: [{
                type: Input
            }], codeTheme: [{
                type: Input
            }], showLineNumbers: [{
                type: Input
            }], useCache: [{
                type: Input
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { NgxGist, NgxGistComponent, gistCodec };
//# sourceMappingURL=proangular-ngx-gist.mjs.map
