import { OnInit } from '@angular/core';
import { DomSanitizer, SafeHtml } from '@angular/platform-browser';
import { HighlightJsTheme, NgxGistThemeService } from './ngx-gist-theme.service';
import { NgxGist } from './ngx-gist.model';
import { NgxGistLineNumbersService } from './ngx-gist-line-numbers.service';
import { NgxGistService } from './ngx-gist.service';
import * as i0 from "@angular/core";
export declare class NgxGistComponent implements OnInit {
    private readonly document;
    private readonly domSanitizer;
    private readonly ngxGistLineNumbersService;
    private readonly ngxGistService;
    private readonly ngxGistThemeService;
    constructor(document: Document, domSanitizer: DomSanitizer, ngxGistLineNumbersService: NgxGistLineNumbersService, ngxGistService: NgxGistService, ngxGistThemeService: NgxGistThemeService);
    /**
     * Display in the DOM only the selected filename(s) from the gists files array.
     *
     * Default: `undefined`
     *
     * Example: `'my-styles.scss'` or `'super-feature.ts'`
     *
     * Tip: Can be either a string or string array. File names much match exactly,
     * be sure to remove any leading or trailing whitespace in the provided strings.
     */
    displayOnlyFileNames?: string | readonly string[];
    /**
     * Optionally hide the gist link which opens the gist on GitHub. The gist links
     * automatically dispaly for remote gists, but can be hidden with this feature.
     *
     * Default: `false`
     */
    hideGistLink: boolean;
    /**
     * Provide a static gist model here directly which will be displayed if
     * no `gistId` is provided for remote fetching. Also this model will be
     * displayed should a fetch fail when retrieving `gistId`, or overwritten
     * once the pertaining `gistId` data is fetched.
     *
     * Default: `undefined`
     */
    set gist(value: NgxGist | undefined);
    private readonly gistSubject;
    readonly gistChanges: import("rxjs").Observable<NgxGist>;
    /**
     * Provide the GitHub gist id to be fetched and loaded. This can be found in
     * URL of the gists you create. For example the id `TH1515th31DT0C0PY` in:
     * https://gist.github.com/FakeUserName/TH1515th31DT0C0PY
     *
     * Default: `undefined`
     *
     * Tip: Alternatively, provide a value directly in the sibling input `gist`.
     */
    set gistId(value: string);
    private readonly gistIdSubject;
    readonly gistIdChanges: import("rxjs").Observable<string>;
    /**
     * The `highlight.js` code theme to use and display.
     *
     * Default: `undefined`
     *
     * Note: Only _one_ theme can be loaded on a single page at a time! The first
     * theme to load will apply to all gists on the page.
     */
    codeTheme?: HighlightJsTheme;
    /**
     * Display or hide the line numbers in your gist code snippets.
     *
     * Default: `true`
     */
    showLineNumbers: boolean;
    /**
     * Cache the GitHub gist request in local memory for 24 hours. GitHub has a
     * request limit, so this helps in reducing bandwidth. Loads previously
     * fetched gist content from the users machine on refresh and page re-visits.
     *
     * Default: `true`
     */
    useCache: boolean;
    ngOnInit(): Promise<void>;
    private fetchAndSetGist;
    private setHljsTheme;
    applyLineNumbers(highlightedConent: string): SafeHtml | null;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxGistComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxGistComponent, "ngx-gist", never, { "displayOnlyFileNames": { "alias": "displayOnlyFileNames"; "required": false; }; "hideGistLink": { "alias": "hideGistLink"; "required": false; }; "gist": { "alias": "gist"; "required": false; }; "gistId": { "alias": "gistId"; "required": false; }; "codeTheme": { "alias": "codeTheme"; "required": false; }; "showLineNumbers": { "alias": "showLineNumbers"; "required": false; }; "useCache": { "alias": "useCache"; "required": false; }; }, {}, never, never, true, never>;
}
